Module opcode

Module opcode 

Pact OpCodes

Structs

Comparator
Comparator OpCode Structure
Conjunction
Conjunction OpCode Structure
OpIndices
Comparator OpCode Structure
SubjectSource
A source for a subject for comparison

Enums

LoadSource
Indicates whether the source of a load is an Input or stored on the compiled DataTable
OpCode
Data structure which breaks down the anatomy of an OpCode
OpComp
Enum of avaliable comparator OpCode operations
OpConj
Enum of avaliable conjunction OpCode operations
OpLoad
Enum to determine whether a comparator OpCode is comparing input to datatable or input to input