Pact OpCodes
Structs
- Comparator
- Comparator OpCode Structure
- Conjunction
- Conjunction OpCode Structure
- OpIndices
- Comparator OpCode Structure
- Subject
Source - A source for a subject for comparison
Enums
- Load
Source - Indicates whether the source of a load is an
Inputor stored on the compiledDataTable - OpCode
- Data structure which breaks down the anatomy of an OpCode
- OpComp
- Enum of avaliable comparator OpCode operations
- OpConj
- Enum of avaliable conjunction OpCode operations
- OpLoad
- Enum to determine whether a comparator OpCode is comparing input to datatable or input to input